@@ -41,7 +41,7 @@
     <message>
         <location filename="../mainwindow.ui" line="192"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Показати довідку</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="195"/>
@@ -51,17 +51,17 @@
     <message>
         <location filename="../mainwindow.ui" line="202"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="231"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>Про цю програму</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="234"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>Про...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="241"/>
@@ -71,7 +71,7 @@
     <message>
         <location filename="../mainwindow.ui" line="273"/>
         <source>Quit application</source>
-        <translation type="unfinished"></translation>
+        <translation>Закрити програму</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="276"/>
@@ -86,7 +86,7 @@
     <message>
         <location filename="../mainwindow.ui" line="321"/>
         <source>Apply</source>
-        <translation type="unfinished"></translation>
+        <translation>Застосувати</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="349"/>
@@ -187,12 +187,12 @@
     <message>
         <location filename="../mainwindow.cpp" line="262"/>
         <source>About</source>
-        <translation type="unfinished"></translation>
+        <translation>Про</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="263"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>Версія:</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="264"/>
@@ -202,18 +202,18 @@
     <message>
         <location filename="../mainwindow.cpp" line="266"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="267"/>
         <location filename="../mainwindow.cpp" line="277"/>
         <source>License</source>
-        <translation type="unfinished"></translation>
+        <translation>Ліцензія</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="268"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Список змін</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="269"/>
@@ -223,7 +223,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="290"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Закрити</translation>
     </message>
 </context>
 <context>
@@ -231,7 +231,7 @@
     <message>
         <location filename="../main.cpp" line="52"/>
         <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
+        <translation>Цю програму потрібно запускати від root.</translation>
     </message>
 </context>
 </TS>
